@@ -17,13 +17,13 @@
 using namespace Akonadi;
 
 CalendarClipboardPrivate::CalendarClipboardPrivate(const Akonadi::CalendarBase::Ptr &calendar, Akonadi::IncidenceChanger *changer, CalendarClipboard *qq)
-    : QObject()
-    , m_calendar(calendar)
+    : m_calendar(calendar)
     , m_changer(changer)
     , q(qq)
 {
     Q_ASSERT(m_calendar);
     if (!m_changer) {
+        /* cppcheck-suppress knownPointerToBool */
         m_changer = new Akonadi::IncidenceChanger(this);
         m_changer->setHistoryEnabled(false);
         m_changer->setGroupwareCommunication(false);
@@ -56,17 +56,17 @@ void CalendarClipboardPrivate::getIncidenceHierarchy(const KCalendarCore::Incide
 
 void CalendarClipboardPrivate::cut(const KCalendarCore::Incidence::List &incidences)
 {
-    const bool result = m_dndfactory->copyIncidences(incidences);
+    const bool copyResult = m_dndfactory->copyIncidences(incidences);
     m_pendingChangeIds.clear();
     // Note: Don't use DndFactory::cutIncidences(), it doesn't use IncidenceChanger for deletion
     // we would loose async error handling and redo/undo features
-    if (result) {
-        Akonadi::Item::List items = m_calendar->itemList(incidences);
-        const int result = m_changer->deleteIncidences(items);
-        if (result == -1) {
+    if (copyResult) {
+        Akonadi::Item::List const items = m_calendar->itemList(incidences);
+        const int deleteResult = m_changer->deleteIncidences(items);
+        if (deleteResult == -1) {
             Q_EMIT q->cutFinished(/**success=*/false, i18n("Error performing deletion."));
         } else {
-            m_pendingChangeIds << result;
+            m_pendingChangeIds << deleteResult;
         }
     } else {
         Q_EMIT q->cutFinished(/**success=*/false, i18n("Error performing copy."));
@@ -97,7 +97,7 @@ void CalendarClipboardPrivate::makeChildsIndependent(const KCalendarCore::Incide
                 return;
             }
 
-            KCalendarCore::Incidence::Ptr newIncidence(child->clone());
+            KCalendarCore::Incidence::Ptr const newIncidence(child->clone());
             newIncidence->setRelatedTo(QString());
             childItem.setPayload<KCalendarCore::Incidence::Ptr>(newIncidence);
             const int changeId = m_changer->modifyIncidence(childItem, /*originalPayload*/ child);
@@ -198,7 +198,7 @@ void CalendarClipboard::cutIncidence(const KCalendarCore::Incidence::Ptr &incide
         Q_ASSERT(!uids.isEmpty());
         KCalendarCore::Incidence::List incidencesToCut;
         for (const QString &uid : std::as_const(uids)) {
-            KCalendarCore::Incidence::Ptr child = d->m_calendar->incidence(uid);
+            KCalendarCore::Incidence::Ptr const child = d->m_calendar->incidence(uid);
             if (child) {
                 incidencesToCut << child;
             }
@@ -235,7 +235,7 @@ bool CalendarClipboard::copyIncidence(const KCalendarCore::Incidence::Ptr &incid
         d->getIncidenceHierarchy(incidence, uids);
         Q_ASSERT(!uids.isEmpty());
         for (const QString &uid : std::as_const(uids)) {
-            KCalendarCore::Incidence::Ptr child = d->m_calendar->incidence(uid);
+            KCalendarCore::Incidence::Ptr const child = d->m_calendar->incidence(uid);
             if (child) {
                 incidencesToCopy << child;
             }
